@@ -20,37 +20,21 @@
     )
 )]
 
-#[cfg(feature = "parallel-compilation")]
-macro_rules! maybe_parallel {
-    ($e:ident.($serial:ident | $parallel:ident)) => {
-        $e.$parallel()
-    };
-}
-
-#[cfg(not(feature = "parallel-compilation"))]
-macro_rules! maybe_parallel {
-    ($e:ident.($serial:ident | $parallel:ident)) => {
-        $e.$serial()
-    };
-}
-
 mod code_memory;
-mod compiler;
+mod debug;
 mod instantiate;
 mod link;
-mod object;
+mod mmap_vec;
+mod profiling;
 mod unwind;
 
-pub mod native;
-pub mod trampoline;
-
 pub use crate::code_memory::CodeMemory;
-pub use crate::compiler::{Compilation, CompilationStrategy, Compiler};
 pub use crate::instantiate::{
-    CompilationArtifacts, CompiledModule, ModuleCode, SetupError, SymbolizeContext, TypeTables,
+    finish_compile, subslice_range, CompiledModule, CompiledModuleInfo, SetupError,
+    SymbolizeContext, TypeTables,
 };
-pub use crate::link::link_module;
-pub use wasmtime_cranelift::{blank_sig, wasmtime_call_conv};
+pub use crate::mmap_vec::MmapVec;
+pub use profiling::*;
 
 /// Version number of this crate.
 pub const VERSION: &str = env!("CARGO_PKG_VERSION");
